package de.intevation.mxd.reader;

import java.io.IOException;

import java.awt.Color;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.CharacterMarkerSymbol;
import com.esri.arcgis.display.IColor;
import com.esri.arcgis.support.ms.stdole.Font;

import org.w3c.dom.Element;
import de.intevation.mxd.utils.MapToXMLUtils;

/**
 * Reads character marker symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class CharacterMarkerSymbolReader implements ISymbolReader{

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(CharacterMarkerSymbolReader.class);

    /**
     * Private member.
     */
    private Element renderer;
    private CharacterMarkerSymbol symbol;
    private MapToXMLUtils util;


    public CharacterMarkerSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof CharacterMarkerSymbol) {
            this.symbol = (CharacterMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a CharacterMarkerSymbol!");
        }
    }

    /**
     * Setter for the parent XML element.
     *
     * @param parent The XML parent node.
     */
    public void setParent(Element parent) {
        this.renderer = parent;
    }

    /**
     * Setter for XML document helper.
     *
     * @param util The helper class for storing map information.
     */
    public void setUtil(MapToXMLUtils util) {
        this.util = util;
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws IOException {
        logger.debug("read()");
        Element symbolElement;
        try {
            symbolElement = util.addSymbol(renderer);
        }
        catch(Exception e) {
            e.printStackTrace();
            return null;
        }

        IColor c = symbol.getColor();
        symbolElement.setAttribute(
            "angle",
            String.valueOf(symbol.getAngle()));
        symbolElement.setAttribute(
            "size",
            String.valueOf(symbol.getSize()));
        symbolElement.setAttribute(
            "x_offset",
            String.valueOf(symbol.getXOffset()));
        symbolElement.setAttribute(
            "y_offset",
            String.valueOf(symbol.getYOffset()));
        symbolElement.setAttribute(
            "color",
            String.valueOf(c.getRGB()));
        symbolElement.setAttribute(
            "tranparency",
            String.valueOf(c.getTransparency()));
        symbolElement.setAttribute(
            "name",
            symbol.getNameString());
        Font f = symbol.getFont();
//TODO Read the font attributes.
        symbolElement.setAttribute("style", "char");
        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
